@@ -1,7 +1,5 @@
 ( cd opt/kde/share/doc/HTML/hu/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ark ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kab ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kab ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kdf ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kdm ; rm -rf common )
@@ -10,10 +8,6 @@
 ( cd opt/kde/share/doc/HTML/hu/kit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kpf ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kpm ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kpm ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/krn ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/krn ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ktuberling ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/amor ; rm -rf common )
@@ -26,26 +20,32 @@
 ( cd opt/kde/share/doc/HTML/hu/kdvi ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kgeo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kgeo ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/klpq ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/klpq ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kmix ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kodo ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kolf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kolf ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kpat ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/korn ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/krfb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/krfb ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/ksim ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/ksim ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kalzium ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kalzium ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/katomic ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/katomic ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ksysguard ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kbounce ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/columbo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/columbo ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kbattleship ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kaboodle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kaboodle ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/khangman ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/khangman ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kfloppy ; rm -rf common )
@@ -64,6 +64,8 @@
 ( cd opt/kde/share/doc/HTML/hu/kedit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kfind ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kiten ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kiten ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kjots ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kjots ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kmoon ; rm -rf common )
@@ -88,12 +90,14 @@
 ( cd opt/kde/share/doc/HTML/hu/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/klipper ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/klprfax ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/klprfax ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kompare ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kompare ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/konsole ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kpackage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kpackage ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/khelpcenter/quickstart ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/khelpcenter/glossary ; rm -rf common )
@@ -112,18 +116,20 @@
 ( cd opt/kde/share/doc/HTML/hu/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kweather ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kwuftpd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kbugbuster ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kljettool ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kljettool ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kioslave ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/flashkard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/flashkard ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kxconfig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kxconfig ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf qpl-license.html )
@@ -150,16 +156,28 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf 9.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/9.png 9.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf headerbg.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf gpl-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf mainheader.html )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf grad.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doxygen.css )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf web-doctop.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-default.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kmenu.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf footer.html )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doctop1.png )
@@ -168,6 +186,8 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf docheadergears.png )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf doctop1a.png )
@@ -178,10 +198,14 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf lgpl-license )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf mainfooter.html )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf bottom1.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf bottom2.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
+( cd opt/kde/share/doc/HTML/hu/common ; rm -rf header.html )
+( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/header.html header.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf kde-localised.css.template )
@@ -192,16 +216,50 @@
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/hu/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/hu/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/HTML/hu/artsbuilder ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/smb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/powerctrl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kalarmd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/cache ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kmixcfg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/lanbrowser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/colors ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmlaunch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmktalkd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmcss ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/laptop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kxmlrpcd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmsmserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmkonsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmlowbatcrit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmlowbatwarn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmfontinst ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kamera ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kamera ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kasteroids ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kfract ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kfract ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/keduca ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/keduca ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kicker ; rm -rf common )
@@ -218,18 +276,20 @@
 ( cd opt/kde/share/doc/HTML/hu/kpaint ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kpoker ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
-( cd opt/kde/share/doc/HTML/hu/kscore ; rm -rf common )
-( cd opt/kde/share/doc/HTML/hu/kscore ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kruler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kruler ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ksnake ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ksnake ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kspell ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/ktimer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/ktimer ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/ktouch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/ktouch ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kwrite ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/megami ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/megami ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kreversi ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/noatun ; rm -rf common )
@@ -238,6 +298,8 @@
 ( cd opt/kde/share/doc/HTML/hu/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kblackbox ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kcharselect ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kcharselect ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kuickshow ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kiconedit ; rm -rf common )
@@ -246,8 +308,12 @@
 ( cd opt/kde/share/doc/HTML/hu/klettres ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kaphorism ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kaphorism ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kghostview ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kpovmodeler ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kenolaba ; rm -rf common )
@@ -260,5 +326,41 @@
 ( cd opt/kde/share/doc/HTML/hu/ksokoban ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kteatime ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kmathtool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kmathtool ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/pci ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/usb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/nics ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/interrupts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/blockdevices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/xserver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/sound ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/partitions ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/pcmcia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/processor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/ioports ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
 ( cd opt/kde/share/doc/HTML/hu/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/hu/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
+( cd opt/kde/share/doc/HTML/hu/atlantik ; rm -rf common )
+( cd opt/kde/share/doc/HTML/hu/atlantik ; ln -sf /opt/kde/share/doc/HTML/hu/common common )
